/*
 Copyright (C) 2013 Stefano Zanotti @ C&D Elettronica.

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Font.h"
#include <string.h>

namespace FlashMat_lite {

uint16_t Font::chr(uint8_t charNum, uint8_t byteNum) const{
    return byteNum + charNum * 10;
}

int8_t Font::x0(uint8_t c) const {
	if (c == 0) {
		return 0;
	}

	return (int8_t) pgm_read_byte(&_chars[chr(c,0)]);
}

uint8_t Font::width(uint8_t c) const {
	if (c == 0) {
		return 0;
	}

	return pgm_read_byte(&_chars[chr(c,1)]);
}

void Font::getMask(uint8_t c, uint8_t mask[8]) const {
	if (c == 0) {
		memset(mask, 0, 8);
		return;
	}

	const uint8_t* b /*PROGMEM*/ = _chars + chr(c, 2);
    
	// read the bytes of the mask
	for (uint8_t n = 0; n < 8; n++) {
		*(mask++) = pgm_read_byte(b++);
	}
}

Font::Font(const uint8_t* chars/*PROGMEM*/) :
		_chars(chars) {
}

}
