/*
 Copyright (C) 2013 Stefano Zanotti @ C&D Elettronica.

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PAINTER_H_
#define PAINTER_H_

/*
 * Provides some utilities to draw on a frame buffer.
 * The frame buffer must be divided into three color planes (R, G, B), not interleaved (i.e. RRRGGGBBB
 * and not RGBRGBRGB).
 * The order of the planes, the color depth and the width and height are all determined by 'fmatdef.h'.
 */

#include <Arduino.h>
#include <inttypes.h>
#include <string.h>
#include "fmatdef.h"
#include "Text.h"
#include "bitWrite.h"
#include "Gradient.h"

namespace FlashMat_lite {

class Painter {
public:
    static uint8_t getPixel(const uint8_t buff[FRAME_SIZE],
                            uint8_t colorPlane, uint8_t x, uint8_t y);
                            
    static void setPixel(uint8_t value, uint8_t buff[FRAME_SIZE],
                         uint8_t colorPlane, uint8_t x, uint8_t y);

    static void fill(uint8_t buff[FRAME_SIZE],
                     const uint8_t color[3]);

    static void copyBuffer(uint8_t dst[FRAME_SIZE],
                           const uint8_t src[FRAME_SIZE]);
    
    static void drawPixel(uint8_t buff[FRAME_SIZE],
                          uint8_t x, uint8_t y, const uint8_t color[3]);
                          
    static void drawLineH(uint8_t buff[FRAME_SIZE],
                          uint8_t x0, uint8_t x1, uint8_t y, const uint8_t color[3]);
    static void drawLineV(uint8_t buff[FRAME_SIZE],
                          uint8_t x, uint8_t y0, uint8_t y1, const uint8_t color[3]);
    static void drawLine(uint8_t buff[FRAME_SIZE],
                         uint8_t x0, uint8_t y0, uint8_t x1, uint8_t y1, const uint8_t color[3]);
    
    static void drawRect(uint8_t buff[FRAME_SIZE],
                         uint8_t x0, uint8_t y0, uint8_t x1, uint8_t y1, const uint8_t color[3], bool filled);
    
    static void drawGradient(uint8_t buff[FRAME_SIZE],
                             const uint8_t color1[3], const uint8_t color2[3], Gradient type);
    
    static void drawText(uint8_t buff[FRAME_SIZE],
                         const Text& text);
        
private:
    Painter(); // unused
    
    // helpers to draw gradients
    static void drawGradientStraight(uint8_t buff[FRAME_SIZE],
                                     const uint8_t color1[3], const uint8_t color2[3], bool vert);
    static void drawGradientDiagonal(uint8_t buff[FRAME_SIZE],
                                     const uint8_t color1[3], const uint8_t color2[3], bool upward);
    static void drawGradientCenter(uint8_t buff[FRAME_SIZE],
                                   const uint8_t color1[3], const uint8_t color2[3], bool square);
                                   
    #if COLOR_DEPTH == 2
        static uint8_t packDuplColor2(uint8_t color);
    #endif
    
    static void swap(uint8_t& a, uint8_t& b);
};

} // namespace
#endif /* PAINTER_H_ */