/*
 Copyright (C) 2013 Stefano Zanotti @ C&D Elettronica.

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHARACTERS_H_
#define CHARACTERS_H_

namespace FlashMat_lite {
// custom-extended Windows-1252 character encodings: added some special
// letters, greek letters, arrows, comparison operators, ...
#define CHR_NULL                   0
#define CHR_alpha                  1
#define CHR_beta                   2
#define CHR_gamma                  3
#define CHR_delta                  4
#define CHR_epsilon                5
#define CHR_theta                  6
#define CHR_lambda                 7
#define CHR_TAB_SIGN               8
#define CHR_TAB                    9 // just a symbol (can be used as a wide space)
#define CHR_NEWLINE               10 // used to go to a new line. never printed
#define CHR_CURSOR                11
#define CHR_INFINITY              12
#define CHR_CARRIAGE_RETURN       13 // never used as newline, just a symbol
#define CHR_pi                    14
#define CHR_rho                   15
#define CHR_sigma                 16
#define CHR_phi                   17
#define CHR_psi                   18
#define CHR_omega                 19
#define CHR_DELTA                 20
#define CHR_PI                    21
#define CHR_SIGMA                 22
#define CHR_OMEGA                 23
#define CHR_RIGHT_ARROW           24
#define CHR_LEFT_ARROW            25
#define CHR_UP_ARROW              26
#define CHR_DOWN_ARROW            27
#define CHR_LTE                   28
#define CHR_NEQ                   29
#define CHR_GTE                   30
#define CHR_APPROX                31
#define CHR_SPACE                 32
#define CHR_EXCL                  33
#define CHR_DBL_QUOTE             34
#define CHR_HASH                  35
#define CHR_DOLLAR                36
#define CHR_PERCENT               37
#define CHR_AMPERSAND             38
#define CHR_QUOTE                 39
#define CHR_LEFT_PARENS           40
#define CHR_RIGHT_PARENS          41
#define CHR_ASTERISK              42
#define CHR_PLUS                  43
#define CHR_COMMA                 44
#define CHR_MINUS                 45
#define CHR_DOT                   46
#define CHR_SLASH                 47
#define CHR_0                     48
#define CHR_1                     49
#define CHR_2                     50
#define CHR_3                     51
#define CHR_4                     52
#define CHR_5                     53
#define CHR_6                     54
#define CHR_7                     55
#define CHR_8                     56
#define CHR_9                     57
#define CHR_COLON                 58
#define CHR_SEMICOLON             59
#define CHR_LT                    60
#define CHR_EQ                    61
#define CHR_GT                    62
#define CHR_QUESTION              63
#define CHR_AT                    64
#define CHR_A                     65
#define CHR_B                     66
#define CHR_C                     67
#define CHR_D                     68
#define CHR_E                     69
#define CHR_F                     70
#define CHR_G                     71
#define CHR_H                     72
#define CHR_I                     73
#define CHR_J                     74
#define CHR_K                     75
#define CHR_L                     76
#define CHR_M                     77
#define CHR_N                     78
#define CHR_O                     79
#define CHR_P                     80
#define CHR_Q                     81
#define CHR_R                     82
#define CHR_S                     83
#define CHR_T                     84
#define CHR_U                     85
#define CHR_V                     86
#define CHR_W                     87
#define CHR_X                     88
#define CHR_Y                     89
#define CHR_Z                     90
#define CHR_LEFT_BRACKET          91
#define CHR_BSLASH                92
#define CHR_RIGHT_BRACKET         93
#define CHR_CIRCUM                94
#define CHR_UNDERSCORE            95
#define CHR_BACKTICK              96
#define CHR_a                     97
#define CHR_b                     98
#define CHR_c                     99
#define CHR_d                    100
#define CHR_e                    101
#define CHR_f                    102
#define CHR_g                    103
#define CHR_h                    104
#define CHR_i                    105
#define CHR_j                    106
#define CHR_k                    107
#define CHR_l                    108
#define CHR_m                    109
#define CHR_n                    110
#define CHR_o                    111
#define CHR_p                    112
#define CHR_q                    113
#define CHR_r                    114
#define CHR_s                    115
#define CHR_t                    116
#define CHR_u                    117
#define CHR_v                    118
#define CHR_w                    119
#define CHR_x                    120
#define CHR_y                    121
#define CHR_z                    122
#define CHR_LEFT_BRACE           123
#define CHR_PIPE                 124
#define CHR_RIGHT_BRACE          125
#define CHR_TILDE                126
#define CHR_RECT                 127
#define CHR_EURO                 128
#define CHR_LOZENGE              129
#define CHR_LOW_QUOTE            130
#define CHR_FLORIN               131
#define CHR_LOW_DBL_QUOTE        132
#define CHR_ELLIPSIS             133
#define CHR_DAGGER               134
#define CHR_DBL_DAGGER           135
#define CHR_CIRCUM_HIGH          136
#define CHR_PER_MILLE            137
#define CHR_S_CARON              138
#define CHR_LEFT_ANGLE_BRACKET   139
#define CHR_OE                   140
#define CHR_L_STROKE             141
#define CHR_Z_CARON              142
#define CHR_DOTLESS_i            143
#define CHR_CHECKMARK            144
#define CHR_LEFT_QUOTE           145
#define CHR_RIGHT_QUOTE          146
#define CHR_LEFT_DBL_QUOTE       147
#define CHR_RIGHT_DBL_QUOTE      148
#define CHR_BULLET               149
#define CHR_EN_DASH              150
#define CHR_EM_DASH              151
#define CHR_TILDE_HIGH           152
#define CHR_TRADEMARK            153
#define CHR_s_CARON              154
#define CHR_RIGHT_ANGLE_BRACKET  155
#define CHR_oe                   156
#define CHR_l_STROKE             157
#define CHR_z_CARON              158
#define CHR_Y_UML                159
#define CHR_NBSP                 160 // just a symbol (can be used as half space)
#define CHR_EXCL_INV             161
#define CHR_CENT                 162
#define CHR_POUND                163
#define CHR_CURRENCY             164
#define CHR_YEN                  165
#define CHR_BROKEN_BAR           166
#define CHR_SECTION              167
#define CHR_UMLAUT               168
#define CHR_COPYRIGHT            169
#define CHR_a_ORDINAL            170
#define CHR_LEFT_GUILL           171
#define CHR_NOT                  172
#define CHR_SHY                  173 // soft hyphen (used just like any other symbol)
#define CHR_REGISTERED           174
#define CHR_MACRON               175
#define CHR_DEGREE               176
#define CHR_PLUS_MINUS           177
#define CHR_POWER_2              178
#define CHR_POWER_3              179
#define CHR_ACUTE                180
#define CHR_mu                   181
#define CHR_PARAGRAPH            182
#define CHR_CDOT                 183
#define CHR_CEDILLA              184
#define CHR_POWER_1              185
#define CHR_o_ORDINAL            186
#define CHR_RIGHT_GUILL          187
#define CHR_ONE_QUARTER          188
#define CHR_ONE_HALF             189
#define CHR_THREE_QUARTER        190
#define CHR_QUESTION_INV         191
#define CHR_A_GRAVE              192
#define CHR_A_ACUTE              193
#define CHR_A_CIRCUM             194
#define CHR_A_TILDE              195
#define CHR_A_UML                196
#define CHR_A_RING               197
#define CHR_AE                   198
#define CHR_C_CEDILLA            199
#define CHR_E_GRAVE              200
#define CHR_E_ACUTE              201
#define CHR_E_CIRCUM             202
#define CHR_E_UML                203
#define CHR_I_GRAVE              204
#define CHR_I_ACUTE              205
#define CHR_I_CIRCUM             206
#define CHR_I_UML                207
#define CHR_ETH                  208
#define CHR_N_TILDE              209
#define CHR_O_GRAVE              210
#define CHR_O_ACUTE              211
#define CHR_O_CIRCUM             212
#define CHR_O_TILDE              213
#define CHR_O_UML                214
#define CHR_TIMES                215
#define CHR_O_STROKE             216
#define CHR_U_GRAVE              217
#define CHR_U_ACUTE              218
#define CHR_U_CIRCUM             219
#define CHR_U_UML                220
#define CHR_Y_ACUTE              221
#define CHR_THORN                222
#define CHR_SZ                   223
#define CHR_a_GRAVE              224
#define CHR_a_ACUTE              225
#define CHR_a_CIRCUM             226
#define CHR_a_TILDE              227
#define CHR_a_UML                228
#define CHR_a_RING               229
#define CHR_ae                   230
#define CHR_c_CEDILLA            231
#define CHR_e_GRAVE              232
#define CHR_e_ACUTE              233
#define CHR_e_CIRCUM             234
#define CHR_e_UML                235
#define CHR_i_GRAVE              236
#define CHR_i_ACUTE              237
#define CHR_i_CIRCUM             238
#define CHR_i_UML                239
#define CHR_eth                  240
#define CHR_n_TILDE              241
#define CHR_o_GRAVE              242
#define CHR_o_ACUTE              243
#define CHR_o_CIRCUM             244
#define CHR_o_TILDE              245
#define CHR_o_UML                246
#define CHR_DIV                  247
#define CHR_o_STROKE             248
#define CHR_u_GRAVE              249
#define CHR_u_ACUTE              250
#define CHR_u_CIRCUM             251
#define CHR_u_UML                252
#define CHR_y_ACUTE              253
#define CHR_thorn                254
#define CHR_y_UML                255

}

#endif /* CHARACTERS_H_ */
