/*
 Copyright (C) 2013 C&D Elettronica.

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <Arduino.h>
#include <inttypes.h>

#include "FlashMat_lite.h"

using namespace FlashMat_lite;

// NOTE: if you create any function that has a FlashMat's class (Text, Gradient, etc.) as an argument
// or as the return value, you MUST declare it here.
// e.g. if you have:
//     Text getMyDefaultTextParameters(int myPar1, bool myPar2) {
//         Text myTextPars;
//         ... some stuff to set the parameters ...
//         return myTextPars;
//     }
// you must add here this declaration:
//     Text getMyDefaultTextParameters(int myPar1, bool myPar2);
// The declaration must match EXACTLY the definition (same types, same names for the parameters, same
// spaces), and they must be placed here, before any function and after the 'using namespace' line.
// If you forget to do that, you'll get obscure errors from Arduino IDE, like "'Text' does not name a type"
// on a line that doesn't even have "Text" in it (the problem is caused by some transformations that
// the Arduino does on your .ino file automatically before verifying/compiling it, and sometimes
// it gets them wrong).

uint8_t red  [3] = MAKE_RGB(255, 0, 0); // A simple way to initialize a color
uint8_t green[3] = MAKE_RGB(0, 255, 0);
uint8_t blue [3];

Text text;

// The object you need to draw on the matrix is 'fm'.
// you can rename it like this, if you like:
//FlashMat& flashmat = fm;
//FlashMat& canvas = fm;
//FlashMat& myLedMatrix = fm;
// ...

void setup() {
    // A different way to create/manipulate a color
    blue[R] = 0;
    blue[G] = 0;
    blue[B] = 255;
    
    fm.setup();
    
    //fm.setText("Hello"); // an example message
    fm.setTextColor(blue);
    //fm.setTextBgColor(red); // the solid background (used if overlay==false)
    fm.setTextOverlay(true); // draw with transparent background
    //fm.setTextPosition(0,0); // this will be changed in the loop
    
    //fm.setTextFont(Fonts::getFont(0)); // choose the font by its number ('0' is already chosen by default)
    
    // fancy "Hello"
    char str[6] = { 'H',
                    CHR_epsilon, // constants defined in 'characters.h'
                    CHR_l_STROKE,
                    CHR_l_STROKE,
                    CHR_o_UML };
    fm.setText(str);
}

void loop() {
    // 'fm' is the main object you need use to draw on the led matrix of one FlashMat board.
    // The only other object you need is one (or more) instance of Text, which you will pass to
    // cell to draw a string using custom parameters.
    // If you only need one text instance at a time, you can use the one stored inside the cell itself,
    // for which special cell's methods are provided
    //
    // 'fm' has two "canvas" (frame buffers) on which it can draw.
    // The 'front' buffer is the one currently displayed and cannot be drawn onto.
    // The 'back' buffer is invisible and can be drawn onto.
    // Only when you are done drawing to the back buffer you call swapBuffers()
    // to update the image shown by the matrix; this way the image won't "appear bit by bit",
    // The transition between frames will be very clean.
    //
    // To receive data from the outside world, you can use the I2C buffer (e.g. the Wire library),
    // but this is not automatically handled by 'fm'.
    //
    // Also look at the 'fmatdef.h' file to configure the options as you need.
    
    int16_t w;
    fm.getText().getStringPixelSize(&w, 0); // get the actual width of the string
    
    for (int x = MATRIX_COLS; x >= -w; --x) {         // scroll the string from the right to the left
        fm.drawGradient(red, green, GRAD_SOUTH_WEST); // draw a nice background
        fm.setTextPosition(x, 0);                     // used to scroll the text right-to-left
        fm.drawText();                                // draw the text (over the current background, since we chose overlay==true)
        fm.show();                                    // the image is complete: show it
        delay(150);                                   // gives the speed for the scrolling
                                                      // (it would be better to measure times with millis(),
                                                      // but for a simple example, using the delay is easier)
    }
    
    // Other drawing functions
    
    // fill with plain color
    //fm.fill(red);
    
    // draw a line (from the top-left to the bottom-right corner)
    // remember that (0,0) is the topleft corner!
    //fm.drawLine(0, 0, MATRIX_COLS - 1, MATRIX_ROWS - 1, green); 
                                                                  
    //fm.drawRect(1, 1, 6, 6, blue, true); // draw a filled rectangle from (1,1) to (6,6)
    
    //fm.drawPixel(0, 0, red); // change the color of a single pixel
    
    // center the text horizontally and vertically (all text parameters must have already been set;
    // if you change them you will need to call this function again)
    //fm.centerText();
    
    // get the currently set color (of the back buffer, not of the currently visible image)
    //uint8_t redValue   = fm.getPixel(0, 0, R);
    //uint8_t greenValue = fm.getPixel(0, 0, G);
    //uint8_t blueValue  = fm.getPixel(0, 0, B);
    
    // get the currently set color (of the currently shown image)
    //uint8_t redValue   = fm.getPixelShown(0, 0, R);
    //uint8_t greenValue = fm.getPixelShown(0, 0, G);
    //uint8_t blueValue  = fm.getPixelShown(0, 0, B);
    
    // copy the currently shown image, to be able to draw over it (without redrawing it from scratch)
    //fm.copyBuffer();
}
